@@ -29,7 +29,9 @@ public:
 
 protected:
     void readProcessInfo(int pid) override;
+    bool readProcessName(int pid) override;
     bool readCurrentDir(int pid) override;
+    bool readArguments(int pid) override;
     void readUserName(void) override;
 };
 
