@@ -18,13 +18,13 @@ namespace Konsole
 /**
  * A terminal character decoder which produces pretty HTML markup
  */
-class KONSOLEDECODERS_EXPORT HTMLDecoder : public TerminalCharacterDecoder
+class HTMLDecoder : public TerminalCharacterDecoder
 {
 public:
     /**
      * Constructs an HTML decoder using a default black-on-white color scheme.
      */
-    explicit HTMLDecoder(const QString &colorSchemeName = QString(), const QFont &profileFont = QFont());
+    explicit HTMLDecoder(const QColor *colorTable, const QFont &profileFont = QFont());
 
     void decodeLine(const Character *const characters, int count, LineProperty properties) override;
 
@@ -36,7 +36,6 @@ private:
     void closeSpan(QString &text);
 
     QTextStream *_output;
-    QString _colorSchemeName;
     QFont _profileFont;
     QColor _colorTable[TABLE_COLORS];
     bool _innerSpanOpen;
