@@ -282,6 +282,9 @@ public:
         /** (bool) Whether to use font's line characters instead of the
          * builtin code. */
         UseFontLineCharacters,
+        /** (bool) Whether to use font's Braille characters instead of the
+         * builtin code. */
+        UseFontBrailleCharacters,
         /** (bool) Whether new sessions should be started in the same
          * directory as the currently active session.
          */
@@ -380,6 +383,12 @@ public:
         /** (QFont) Emoji font override
          */
         EmojiFont,
+        /** (QColor) Color for scrollbar markers */
+        MarkerColor,
+        /** (double) Size of a scrollbar marker
+         * as a percentage of scrollbar length
+         */
+        MarkerSize,
         /** When to show line numbers.
          * 0 for Never, 1 when showing URL hints, 2 for always
          */
