@@ -33,7 +33,6 @@
 #include "profile/ProfileManager.h"
 
 #include "Session.h"
-#include "SessionController.h"
 
 #include "terminalDisplay/TerminalDisplay.h"
 #include "terminalDisplay/TerminalFonts.h"
@@ -352,7 +351,7 @@ void SessionManager::saveSessions(KConfig *config)
         n++;
     }
 
-    KConfigGroup group(config, "Number");
+    KConfigGroup group(config, QStringLiteral("Number"));
     group.writeEntry("NumberOfSessions", _sessions.count());
 }
 
@@ -363,7 +362,7 @@ int SessionManager::getRestoreId(Session *session)
 
 void SessionManager::restoreSessions(KConfig *config)
 {
-    KConfigGroup group(config, "Number");
+    KConfigGroup group(config, QStringLiteral("Number"));
     const int sessions = group.readEntry("NumberOfSessions", 0);
 
     // Any sessions saved?
