@@ -944,7 +944,7 @@ void EditProfileDialog::setupAppearancePage(const Profile::Ptr &profile)
     connect(getNewButton, &KNSWidgets::Button::dialogFinished, this, &Konsole::EditProfileDialog::gotNewColorSchemes);
 
     getNewButton->setText(i18n("Get New..."));
-    getNewButton->setConfigFile(QStringLiteral("konsole.knsrc"));
+    getNewButton->setConfigFile(QStringLiteral(":/konsole/konsole.knsrc"));
     _appearanceUi->colorSchemesBtnLayout->addWidget(getNewButton);
 
     _appearanceUi->enableBidiRenderingButton->setChecked(profile->bidiRenderingEnabled());
@@ -1740,6 +1740,14 @@ void EditProfileDialog::setupScrollingPage(const Profile::Ptr &profile)
     _scrollingUi->reflowLinesButton->setChecked(profile->property<bool>(Profile::ReflowLines));
     connect(_scrollingUi->reflowLinesButton, &QPushButton::clicked, this, &EditProfileDialog::toggleReflowLines);
 
+    // setup marker color button
+    _scrollingUi->markerColorButton->setColor(profile->property<QColor>(Profile::MarkerColor));
+    connect(_scrollingUi->markerColorButton, &KColorButton::changed, this, &Konsole::EditProfileDialog::toggleScrollbarMarkerColor);
+
+    // setup marker size widget
+    _scrollingUi->markerSizeWidget->setValue(profile->property<double>(Profile::MarkerSize));
+    connect(_scrollingUi->markerSizeWidget, &QDoubleSpinBox::valueChanged, this, &Konsole::EditProfileDialog::toggleScrollbarMarkerSize);
+
     // signals and slots
     connect(_scrollingUi->historySizeWidget, &Konsole::HistorySizeWidget::historySizeChanged, this, &Konsole::EditProfileDialog::historySizeChanged);
 }
@@ -1774,6 +1782,16 @@ void EditProfileDialog::toggleReflowLines(bool enable)
     updateTempProfileProperty(Profile::ReflowLines, enable);
 }
 
+void EditProfileDialog::toggleScrollbarMarkerColor(QColor color)
+{
+    updateTempProfileProperty(Profile::MarkerColor, color);
+}
+
+void EditProfileDialog::toggleScrollbarMarkerSize(double pSize)
+{
+    updateTempProfileProperty(Profile::MarkerSize, pSize);
+}
+
 void EditProfileDialog::setupMousePage(const Profile::Ptr &profile)
 {
     _mouseUi->underlineLinksButton->setChecked(profile->property<bool>(Profile::UnderlineLinksEnabled));
